# -------------------------------------------------------------------------------------------
#
# How to build for normal kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-53.el5' ipw3945.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-53.el5' ipw3945.spec
#
# How to build for normal kernel and XEN kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-53.el5' --define 'buildxen 1' ipw3945.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-53.el5' --define 'buildxen 1' ipw3945.spec
#
# How to build for normal kernel and PAE kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-53.el5' --define 'buildPAE 1' ipw3945.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-53.el5' --define 'buildPAE 1' ipw3945.spec
#
# How to build for all kernel (normal, xen, PAE)
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-53.el5' --define 'buildall 1' ipw3945.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-53.el5' --define 'buildall 1' ipw3945.spec
#
#
# How to build for the running kernel:
#
#  rpmbuild -ba --target i686   ipw3945.spec
#  rpmbuild -ba --target x86_64 ipw3945.spec
#
# -------------------------------------------------------------------------------------------

%{!?buildxen:%define buildxen 0}
%{!?buildPAE:%define buildPAE 0}

%{?buildall:%define buildxen 1}
%{?buildall:%define buildPAE 1}

%{?!kernel:%define kernel %(rpm -q kernel-devel | tail -1 | sed -e 's|kernel-devel-||')}

%define kversion %(echo "%{kernel}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernel}" | sed -e 's|.*-||')

%define kernel_src_path %{_usrsrc}/kernels/%{kernel}-%{_target_cpu}
%define kernel_xen_src_path %{_usrsrc}/kernels/%{kernel}-xen-%{_target_cpu}
%define kernel_PAE_src_path %{_usrsrc}/kernels/%{kernel}-PAE-%{_target_cpu}

%define kernel_moduledir /lib/modules/%{kernel}/kernel
%define kernel_xen_moduledir /lib/modules/%{kernel}xen/kernel
%define kernel_PAE_moduledir /lib/modules/%{kernel}PAE/kernel

%define pkg_name ipw3945
%define kmdl_name kernel-module-%{pkg_name}-%{kernel}

# -------------------------------------------------------------------------------------------

Summary: 	Intel® PRO/Wireless 3945ABG/3945BG driver for Linux
Name: 		%{pkg_name}
Version: 	1.2.0
Release: 	2%{?dist}
Epoch:		0
Packager: 	Urs Beyerle <urs.beyerle@psi.ch>
License: 	GPL2/BSD
Group: 		System Environment/Kernel
URL: 		http://ipw3945.sourceforge.net/
Source0: 	http://prdownloads.sourceforge.net/ipw3945/%{name}-%{version}.tgz
BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
# BuildRequires: 	ieee80211-devel >= 1.1.11
Requires:       kernel-module-%{pkg_name} >= %{epoch}:%{version}

BuildRequires:  kernel-devel = %{kernel}, 
BuildRequires:  kernel = %{kernel}
%if %{buildxen}
BuildRequires:  kernel-xen-devel = %{kernel}
BuildRequires:  kernel-xen = %{kernel}
%endif
%if %{buildPAE}
BuildRequires:  kernel-PAE-devel = %{kernel}
BuildRequires:  kernel-PAE = %{kernel}
%endif

%description
The Intel® PRO/Wireless 3945ABG Network Connection driver for Linux is
a unified driver that works on both hardware adapters listed above.


%package -n %{kmdl_name}
Summary: 	Kernel module for the Intel® PRO/Wireless 3945.
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}

%description -n %{kmdl_name}
This package contains kernel drivers for the Intel® PRO/Wireless 3945.

%if %{buildxen}

%package -n %{kmdl_name}xen
Summary: 	Kernel module for the Intel® PRO/Wireless 3945.
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}

%description -n %{kmdl_name}xen
This package contains kernel drivers for the Intel® PRO/Wireless 3945.

%endif


%if %{buildPAE}

%package -n %{kmdl_name}PAE
Summary: 	Kernel module for the Intel® PRO/Wireless 3945.
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}

%description -n %{kmdl_name}PAE
This package contains kernel drivers for the Intel® PRO/Wireless 3945.

%endif



%prep
%setup -n %{pkg_name}-%{version}
grep -rl '<net/ieee80211.h>' . | xargs perl -pi -e's,<net/ieee80211.h>,"net/ieee80211.h",'
perl -pi -e's,/sbin/depmod,:,g' Makefile
grep -rl '#include <linux/config.h>' . | xargs perl -pi -e's,#include <linux/config.h>,/* #include <linux/config.h> */,'

%build
echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"


### kernel
mkdir -p %{buildroot}%{kernel_moduledir}/drivers/net/wireless
make clean
make -C %{kernel_src_path} M=$( pwd )
make KMISC=%{buildroot}%{kernel_moduledir}/drivers/net/wireless install install


%if %{buildxen}
### XEN kernel 
mkdir -p %{buildroot}%{kernel_xen_moduledir}/drivers/net/wireless
make clean
make -C %{kernel_xen_src_path} M=$( pwd )
make KMISC=%{buildroot}%{kernel_xen_moduledir}/drivers/net/wireless install
%endif


%if %{buildPAE}
### PAE kernel 
mkdir -p %{buildroot}%{kernel_PAE_moduledir}/drivers/net/wireless
make clean
make -C %{kernel_PAE_src_path}  M=$( pwd )
make KMISC=%{buildroot}%{kernel_PAE_moduledir}/drivers/net/wireless install
%endif


%install
echo


%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%postun -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :



%if %{buildxen}

%postun -n %{kmdl_name}xen
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}xen
depmod -a %{kernel} >/dev/null 2>&1 || :

%endif


%if %{buildPAE}

%postun -n %{kmdl_name}PAE
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}PAE
depmod -a %{kernel} >/dev/null 2>&1 || :

%endif


%files 
%defattr(-,root,root,-)
%doc README* LICENSE* ISSUES CHANGES

%files -n %{kmdl_name}
%attr(755,root,root) %{kernel_moduledir}/drivers/net/wireless/ipw3945.ko

%if %{buildxen}
%files -n %{kmdl_name}xen
%attr(755,root,root) %{kernel_xen_moduledir}/drivers/net/wireless/ipw3945.ko
%endif


%if %{buildPAE}
%files -n %{kmdl_name}PAE
%attr(755,root,root) %{kernel_PAE_moduledir}/drivers/net/wireless/ipw3945.ko
%endif


%changelog
* Fri Nov 16 2007 Urs Beyerle <urs.beyerle@psi.ch> - 1.2.0-2
- fix kernel_moduledir
- mode 755 for ipw3945.ko

* Thu Mar 15 2007 Urs Beyerle <urs.beyerle@psi.ch> - 1.2.0-1.sl5.psi
- intial build for SL5
